==> v0.1.1.tar.gz: dotsort/src/Abracadabra/GameScene.cpp <==
// SPDX-License-Identifier: GPL-2.0-or-later
// Copyright (c) 2023 Yevhen Babiichuk (DustDFG)

#include <Abracadabra/GameScene.hpp>

#include <DotSort/Game.hpp>

#include <SFML/System/Clock.hpp>

#include <SFML/Graphics/RenderWindow.hpp>

#include <SFML/Window/Event.hpp>
#include <SFML/Window/Keyboard.hpp>

/* Non game stuff */

#include <cstdint>
#include <vector>
#include <random>

#include <SFML/Graphics.hpp>

#include <Abracadabra/VectorTubeSetBuilder.hpp>

#include <iostream> // DEBUG

std::vector<uint8_t> ldots = {
		2, 4, 1, 3,
		4, 0, 3, 2,
		3, 0, 1, 0,
		0, 1, 2, 1,
		2, 4, 3, 4,
	};

GameScene::GameScene(sf::RenderWindow* window)
	: Presenter(new VectorTubeSetBuilder(4, 5, ldots))
	, window(window)
{
	/* Non game stuff */

	this->view = new View::View(this->tubeSet->tubeSize, this->tubeSet->tubeCount, window, this);
}

GameScene::~GameScene()
{
}

void GameScene::load()
{
}

void GameScene::unload()
{
}

void GameScene::update(sf::Time dt)
{
}

void GameScene::processEvent(sf::Event& event)
{
	if(event.type == sf::Event::MouseButtonPressed)
	{
		std::optional<uint8_t> tubeIndex = this->view->getTubeIndex(event);
		if(tubeIndex)
		{
			this->onTubeClick(tubeIndex.value());
		}
		else
		{
			this->selectedTube = this->selectedTube = std::nullopt;
		}
	}
	else if(event.type == sf::Event::KeyPressed)
	{
		if(event.key.code == sf::Keyboard::Space)
		{
			this->onReload();
		}
		else if(event.key.code == sf::Keyboard::R)
		{
			this->newLevel();
		}
	}
}

void GameScene::draw(sf::RenderWindow* window) const
{
	window->clear(sf::Color(70, 70, 70));
	window->draw(*this->view);
	window->display();
}

void GameScene::newLevel()
{
	delete this->view;
	delete this->tubeSet;
	delete this->builder;

	std::random_device dev;
	std::mt19937 rng(dev());
	std::uniform_int_distribution<std::mt19937::result_type> distTubeSize(4,6);
	std::uniform_int_distribution<std::mt19937::result_type> distTubeCount(5,12);

	uint8_t tubeSize = distTubeSize(rng);
	uint8_t tubeCount = distTubeCount(rng);

	this->builder = new VectorTubeSetBuilder(tubeSize, tubeCount, VectorTubeSetBuilder::getRandomVector(tubeSize, tubeCount));
	this->tubeSet = (*this->builder)();
	this->view = new View::View(this->tubeSet->tubeSize, this->tubeSet->tubeCount, this->window, this);
}

==> v0.2.0.tar.gz: dotsort/src/Abracadabra/GameScene.cpp <==
// SPDX-License-Identifier: GPL-2.0-or-later
// Copyright (c) 2023 Yevhen Babiichuk (DustDFG)

#include <Abracadabra/GameScene.hpp>

#include <DotSort/Game.hpp>

#include <SFML/System/Clock.hpp>

#include <SFML/Graphics/RenderWindow.hpp>

#include <SFML/Window/Event.hpp>
#include <SFML/Window/Keyboard.hpp>

/* Non game stuff */

#include <cstdint>
#include <vector>
#include <random>

#include <SFML/Graphics.hpp>

#include <Abracadabra/VectorTubeSetBuilder.hpp>

#include <iostream> // DEBUG

std::vector<uint8_t> ldots = {
		2, 4, 1, 3,
		4, 0, 3, 2,
		3, 0, 1, 0,
		0, 1, 2, 1,
		2, 4, 3, 4,
	};

GameScene::GameScene(sf::RenderWindow* window)
	: window(window)
{
	/* Non game stuff */
	this->initLevel(new VectorTubeSetBuilder(4, 5, ldots));
}

GameScene::~GameScene()
{
}

void GameScene::load()
{
}

void GameScene::unload()
{
}

void GameScene::update(sf::Time dt)
{
}

void GameScene::processEvent(sf::Event& event)
{
	if(event.type == sf::Event::MouseButtonPressed)
	{
		std::optional<uint8_t> tubeIndex = this->view->getTubeIndex(event);
		this->presenter->onClick(tubeIndex);
	}
	else if(event.type == sf::Event::KeyPressed)
	{
		if(event.key.code == sf::Keyboard::Space)
		{
			this->presenter->onReload();
		}
		else if(event.key.code == sf::Keyboard::R)
		{
			this->newLevel();
		}
	}
}

void GameScene::draw(sf::RenderWindow* window) const
{
	window->clear(sf::Color(70, 70, 70));
	window->draw(*this->view);
	window->display();
}

void GameScene::newLevel()
{
	std::random_device dev;
	std::mt19937 rng(dev());
	std::uniform_int_distribution<std::mt19937::result_type> distTubeSize(4,6);
	std::uniform_int_distribution<std::mt19937::result_type> distTubeCount(5,12);

	uint8_t tubeSize = distTubeSize(rng);
	uint8_t tubeCount = distTubeCount(rng);

	auto builder = new VectorTubeSetBuilder(tubeSize, tubeCount, VectorTubeSetBuilder::getRandomVector(tubeSize, tubeCount));

	this->initLevel(builder);
}

void GameScene::initLevel(TubeSetBuilder* builder)
{
	if(this->view)
	{
		delete this->view;
	}
	if(this->presenter)
	{
		delete this->presenter;
	}

	this->presenter = new Presenter(builder);
	this->view = new View::View(this->presenter->tubeSet->tubeSize, this->presenter->tubeSet->tubeCount, this->window, this->presenter);
}
